# -*- coding: UTF-8 -*-
"""parsing du fichier xml du dictionnaire creole *cfgparser.py*
"""

from py.test import raises
from os.path import join, abspath, splitext, dirname, basename

from creole.cfgparser import *
from creole.error import *
from creole.typeole import *
from creole.template import Template
from creole.dom_parser import *
from creole.eosfunc import Param

def setup_module(module):
    "creation d'un eoledict de travail et des fichiers cible"
    module.test_dir = join(abspath(dirname(__file__)), splitext(basename(__file__))[0])
    module.eoledict = EoleDict()

    # création des target (les fichiers cibles sont censés exister)
    for target in ['squid.conf', 'httpd.conf']:
        file_h = file(join('/tmp', target), 'w')
        file_h.close()

    module.files = {
        '/tmp/httpd.conf':{'var': Template('/tmp/httpd.conf',
                           templatedir= test_dir),
                           'hidden':False, 'rm': False,},
        '/tmp/squid.conf':{'var':Template('/tmp/squid.conf',
                           templatedir=test_dir),
                           'hidden':False, 'rm': False,}
        }
    
    module.liste_var = {
    'ip_eth0':  {'description':'ip de la papatte exterieure',
                 'value':['192.168.230.70'],
                 'type':'ip',
                 'hidden':False,
                 'multi':True},
    'netmask_eth0':  {'description':'netmask de la papatte exterieure',
                 'value':['255.255.255.0'],
                 'type':'netmask',
                 'hidden':False,
                 'multi':False},
    'network_eth0':  {'description':'network de la papatte exterieure',
                 'value':[],
                 'type':'ip',
                 'hidden':False,
                 'multi':False},
    'port_rpc':  {'description':'port du backend XMLRPC',
                 'value':['7080'],
                 'type':'number',
                 'hidden':True,
                 'multi':False},
    }

    module.constraints = {
        'conditions':{u'port_rpc':[

        [u'hidden_if_not_in',
            [u'net'],
            [u'ip_eth0', u'netmask_eth0', u'network_eth0'],
            [], [], [{'value':u'0', 'name':'', 'optional': '', 'type':''},
                {'value':u'7080', 'name':'', 'optional':'', 'type':''}]]
        ]},
        'checks':{'port_rpc':[['number',[{'name':'mini','value':'0','type':''},
                                         {'name':'maxi','value':'65535','type':''}]]
                              ]},
        'fills':{'network_eth0':[['calc_network',[{'name':'ip','value':'ip_eth0','type':'eole'},
                                                  {'name':'netmask','value':'netmask_eth0','type':'eole'}]]
                                 ]},
        }
    

    module.variables = {}
    for key, data in liste_var.items():
        checks = []
        fills = []
        if constraints['checks'].has_key(key):
            checks = constraints['checks'][key]
        if constraints['fills'].has_key(key):
            fills = constraints['fills'][key]
        module.variables[key]=  type_factory(
                         mime = data['type'],
                         name = key,
                         valeole = data['value'],
                         description = data['description'],
                         hidden = data['hidden'],
                         checks = checks,
                         fills = fills
                         )

    module.helps = {'variables':{'ip_eth0':u'adresse ip de la carte correspondant à la sortie sur internet'},
                    'families':{'net':u'variables de configuration du réseau'}}
                   
    eoledict.read(join(test_dir,'eole.xml'))
        
def test_read():
    """test du chargement d'un fichier xml dans le dictionnaire
    """
    my_dict = EoleDict()
    my_dict.read(join(test_dir,'eole.xml'))

def test_fichiers():
    """liste des fichiers
    """
    assert eoledict.get_files() == files

def test_vars():
    """liste des variables
    """
    assert eoledict.get_variables() == variables

def test_conditions():
    """liste des dépendances
    """
    assert eoledict.get_constraints() == constraints['conditions']

def test_get_var():
    """test récupération d'une variable
    """
    assert eoledict.get_variable('ip_eth0') == type_factory(mime = 'ip',
                                                            name = 'ip_eth0',
                                                            valeole = ['192.168.230.70'],
                                                            description = 'ip de la papatte exterieure',
                                                            hidden = False,
                                                            multi = True)

def test_help():
    """test de récupération de l'aide
    """
    assert eoledict.helps == helps
    
def test_families():
    """liste des familles 
    """
    families = {'general':{'hidden': False, 'mode':'',
                           'vars':['port_rpc']},
                'net':{'hidden': False, 'mode': '',
                       'vars':['ip_eth0','netmask_eth0','network_eth0']}
               }
    assert eoledict.get_families() == families

def test_groups():
    """liste des groupes
    """
    groups = {'ip_eth0':['netmask_eth0','network_eth0']}
    assert eoledict.get_groups() == groups

def test_set_value():
    """test de la fonction de saisie
    """
    eoledict.set_value('port_rpc','7082')
    #gestion des dépendances
    assert eoledict.variables['ip_eth0'].hidden == True
    assert eoledict.variables['netmask_eth0'].hidden == True
    assert eoledict.variables['network_eth0'].hidden == True
    assert eoledict.families['net']['hidden'] == True
    eoledict.set_value('port_rpc','7080')
    #gestion des dépendances
    assert eoledict.variables['ip_eth0'].hidden == False
    assert eoledict.variables['netmask_eth0'].hidden == False
    assert eoledict.variables['network_eth0'].hidden == False
    assert eoledict.families['net']['hidden'] == False

