/*****************************/
/*  suppression des tables   */
/*****************************/
drop table lock_serveur;
drop table procedures
drop table log_zephir;
drop table groupes_serveurs;
drop table groupes_droits;
drop table serveur_auth;
drop table users;
drop table log_serveur;
drop table services_installes;
drop table serveurs;
drop table services;
drop table variantes;
drop table modules;
drop table etablissements;
drop table types_etab;


/****************************************************/
/*              tables annexes                      */
/****************************************************/

/*-- types d tablissements (collge, lyce...) */
create table types_etab (
  id		serial		PRIMARY KEY,
  libelle	varchar(80)	not null
);

/*-- modules disponibles */
create table modules (
  id		serial		PRIMARY KEY,
  libelle	varchar(40)	not null
);

/*-- services disponibles selon le module */
create table services (
  id		serial		PRIMARY KEY,
  module	integer		not null,
  libelle	varchar(40)	not null,
  FOREIGN KEY(module) REFERENCES modules(id) ON DELETE CASCADE
);

/*-- variantes disponibles selon le module */
create table variantes (
  id			serial		PRIMARY KEY,
  module		integer		not null,
  libelle		varchar(40)	not null,
  owner			varchar(30)	,
  passmd5		varchar(50)	,
  FOREIGN KEY(module) REFERENCES modules(id)
);

/****************************************************/
/*              tables principales                  */
/****************************************************/

/*-- tablissements */
/*-- type en dernier pour gestion spcifique */
create table etablissements (
  rne			varchar(8)		PRIMARY KEY,
  libelle		varchar(100)	not null,
  adresse		varchar(100),
  tel			varchar(20),
  fax			varchar(20),
  mail			varchar(50),
  responsable	varchar(30),
  remarques		text,
  type			integer			not null,
  ville			varchar(50)		not null,
  cp			varchar(5)		not null,
  FOREIGN KEY(type) REFERENCES types_etab(id)
);

/*-- serveurs installs */
create table serveurs (
  id				serial		PRIMARY KEY,
  rne				varchar(8)	not null,
  libelle			varchar(50)	not null,
  materiel			varchar(100),
  processeur		varchar(50),
  disque_dur		varchar(50),
  date_install		date		not null,
  installateur		varchar(50)	not null,
  tel				varchar(20),
  remarques			text,
  module_initial	integer		not null,
  module_actuel		integer		not null,
  variante			integer		not null,
  timestamp			varchar(20)	not null,
  timeout			integer,
  etat				integer,
  last_contact		varchar(20),
  params			varchar(100),
  FOREIGN KEY(rne) REFERENCES etablissements(rne),
  FOREIGN KEY(module_initial) REFERENCES modules(id),
  FOREIGN KEY(module_actuel) REFERENCES modules(id),
  FOREIGN KEY(variante) REFERENCES variantes(id)
);

/*-- groupes de droits */
create table groupes_droits (
  id		serial			PRIMARY KEY,
  libelle	varchar(30)		not null,
  droits	varchar(1500)	not null
);

/*-- groupes de serveurs */
create table groupes_serveurs (
  id		serial			PRIMARY KEY,
  libelle	varchar(30)		not null,
  serveurs	varchar(1500)	not null
);


/*-- services installs */
create table services_installes (
  id_serveur	integer,
  id_service	integer,
  FOREIGN KEY(id_serveur) REFERENCES serveurs(id) ON DELETE CASCADE,
  FOREIGN KEY(id_service) REFERENCES services(id),
  PRIMARY KEY(id_serveur,id_service)
);

/*****************************/
/* table de log des serveurs */
/*****************************/

create table log_serveur (
  id		serial			PRIMARY KEY,
  id_serveur	integer		not null,
  date		timestamp		not null,
  type		varchar(20),
  message	varchar(150)	not null,
  etat		integer			not null,
  FOREIGN KEY(id_serveur) REFERENCES serveurs(id) ON DELETE CASCADE
);

/**************************/
/* table des utilisateurs */
/**************************/

create table users (
  login			varchar(40)		PRIMARY KEY,
  mail			varchar(50),
  nom			varchar(40),
  prenom		varchar(40),
  sms			varchar(20),
  mail_actif	integer			not null,
  sms_actif		integer			not null,
  droits		varchar(400)	not null,
  groupes		varchar(150),
  cle			varchar(2050)
);

/*****************************************/
/* table d'autorisation de connexion ssh */
/*****************************************/
create table serveur_auth (
  id_serveur	integer,
  login			varchar(40),
  FOREIGN KEY(id_serveur)	REFERENCES serveurs(id) ON DELETE CASCADE,
  FOREIGN KEY(login)		REFERENCES users(login) ON DELETE CASCADE,
  PRIMARY KEY(id_serveur,login)
);


/*************************/
/* table de log gnrale */
/*************************/
create table log_zephir (
  id		serial			PRIMARY KEY,
  id_user	varchar(20),
  date		timestamp		not null,
  type		varchar(20),
  message	varchar(150)	not null
);


/*********************************/
/* tables de procdures et locks */
/*********************************/

create table procedures (
  tag		varchar(20)	PRIMARY KEY,
  libelle	varchar(100)
);

create table lock_serveur (
  id_serveur	integer		not null,
  tag			varchar(20)	not null,
  FOREIGN KEY(id_serveur) REFERENCES serveurs(id) ON DELETE CASCADE,
  FOREIGN KEY(tag) REFERENCES procedures(tag) ON DELETE CASCADE
);


/****************************/
/* tables de gestion du vpn */
/****************************/

create table conf_vpn (
  id_sphynx     integer not null,
  id_amon       integer not null,
  etat          integer,
  FOREIGN KEY(id_sphynx)        REFERENCES serveurs(id) ON DELETE CASCADE,
  FOREIGN KEY(id_amon)          REFERENCES serveurs(id) ON DELETE CASCADE,
  PRIMARY KEY(id_sphynx,id_amon)
);


/**********************************************/
/* insertion des groupes de droits par dfaut */
/**********************************************/

insert into groupes_droits values (1,'Lecture', '[\'etabs.get_types\', \'etabs.get_etab\', \'etabs.get_libelle_etab\',\'etabs.rech_etab\', \'services.get_service_installe\', \'services.get_service\', \'services.get_service_module\', \'serveurs.fichiers_zephir\', \'serveurs.global_status\', \'serveurs.get_dico\', \'serveurs.get_serveur\', \'serveurs.get_log\', \'serveurs.serveurs_etab\', \'serveurs.agents_status\', \'serveurs.get_status\', \'serveurs.groupe_serveur\', \'serveurs.get_conf_uucp\', \'serveurs.get_file_content\', \'modules.get_module\', \'modules.get_variante\', \'modules.fichiers_variante\', \'modules.get_var_file\', \'modules.get_dico\', \'uucp.get_checksum\',\'serveurs.get_groupes\',\'get_user\',\'serveurs.get_groups\',\'get_permissions\',\'user_group\',\'edit_user\',\'serveurs.groupe_reload\',\'save_key\',\'serveurs.get_bastion\',\'serveurs.save_group\',\'serveurs.del_group\',\'serveurs.edit_group\',\'serveurs.get_locks\',\'maj_client\',\'uucp.get_actions\', \'uucp.sphynx_list\']');
insert into groupes_droits values (2,'Ecriture', '[\'etabs.edit_etab\', \'etabs.del_etab\', \'etabs.add_etab\', \'etabs.import_etab\', \'etabs.add_type\', \'etabs.del_type\', \'services.del_service_installe\', \'services.add_service\', \'services.del_service\', \'services.add_service_installe\', \'services.edit_service\', \'serveurs.del_serveur\', \'serveurs.conf_ssh\', \'serveurs.edit_serveur\', \'serveurs.add_serveur\', \'serveurs.del_log\', \'serveurs.add_files\', \'serveurs.del_files\', \'modules.del_module\', \'modules.del_variante\', \'modules.add_variante\', \'modules.copy_variante\', \'modules.edit_module\', \'modules.edit_variante\', \'modules.add_module\', \'modules.add_files\', \'modules.del_files\', \'modules.import_variante\']');
insert into groupes_droits values (3,'Actions sur les serveurs', '[\'serveurs.save_conf\', \'serveurs.save_bastion\', \'serveurs.save_bastion_groupe\', \'serveurs.copy_conf\', \'serveurs.set_groupe_var\', \'serveurs.groupe_params\', \'serveurs.get_groupe_vars\', \'serveurs.maj_locks\', \'modules.save_dico\', \'uucp.reconfigure\', \'uucp.install_variante\', \'uucp.configure\', \'uucp.confirm_transfer\', \'uucp.configure_groupe\', \'uucp.save_conf_groupe\', \'uucp.log_serveur\', \'uucp.maj_site\', \'uucp.maj_groupe\', \'uucp.release_lock\', \'uucp.save_files\', \'uucp.install_module\', \'uucp.maj\', \'uucp.save_conf\',\'uucp.purge_actions\',\'uucp.maj_client\',\'uucp.maj_client_groupe\']');
insert into groupes_droits values (4,'Gestion des permissions', '[\'get_permissions\', \'save_permissions\',\'get_user\',\'get_rights\',\'user_group\',\'serveurs.authorize_user\',\'serveurs.deny_user\',\'serveurs.save_group\',\'modules.add_module\',\'etabs.add_type\',\'uucp.install_module\',\'del_user\',\'list_users\']');
insert into groupes_droits values (5,'fonction des clients','[\'uucp.confirm_transfer\', \'uucp.get_checksum\',\'uucp.maj_site\',\'uucp.log_serveur\',\'uucp.save_files\',\'uucp.scan_timeouts\',\'serveurs.get_locks\',\'maj_client\', \'serveurs.get_timeout\']');
insert into groupes_droits values (6,'export de variantes','[\'modules.export_variante\',\'modules.get_variante\']');
insert into groupes_droits values (7,'configuration vpn','[\'uucp.sphynx_add\', \'uucp.sphynx_del\', \'uucp.sphynx_get\']');

alter table serveurs add column params varchar(100);


/**********************************************/
/*  insertion des utilisateurs par dfaut     */
/**********************************************/

insert into users (login,mail_actif,sms_actif,droits) values ('%%admin_zephir%%',0,0,'[1,4]');
insert into users (login,mail_actif,sms_actif,droits) values ('zephir',0,0,'[5]');

/**********************************************/
/*  insertion des procdures par dfaut     */
/**********************************************/

insert into procedures values ('MAJ','Mise  jour (rseau ou cd)');
insert into procedures values ('RECONFIGURE','Reconfiguration du serveur');
insert into procedures values ('INSTANCE','Instanciation du serveur');


/*********************/
/* ajout des indexes */
/*********************/

create index log_id_index ON log_serveur(id_serveur);
create index log_etat_index ON log_serveur(etat);
create index log_type_index ON log_serveur(type);
create index log_date_index ON log_serveur(date);
create index serveurs_rne_index ON serveurs(rne);
create index serveurs_module_index ON serveurs(module_actuel);
create index serveur_etat_index ON serveurs(etat);
create index serveur_timeout_index ON serveurs(timeout);
create index variante_module_index ON variantes(module);
